@@ -15,6 +15,7 @@
 
 import copy
 import datetime
+import inspect
 import requests
 import tacker.conf
 import webob
@@ -49,6 +50,7 @@ from tacker.api.vnflcm.v1 import sync_resource
 from tacker.common import exceptions
 from tacker.common import utils
 from tacker.conductor.conductorrpc import vnf_lcm_rpc
+from tacker.db.db_sqlalchemy import models
 from tacker.db.vnfm import vnfm_db
 from tacker.extensions import nfvo
 from tacker.extensions import vnfm
@@ -148,6 +150,8 @@ def check_vnf_status_and_error_point(action, status=None):
     def outer(f):
         @functools.wraps(f)
         def inner(self, context, vnf_instance, vnf, *args, **kw):
+            LOG.debug("Start %s with context: %s" % (
+                inspect.currentframe().f_code.co_name, context.to_dict()))
             vnf['current_error_point'] = fields.ErrorPoint.INITIAL
 
             if 'before_error_point' not in vnf:
@@ -385,7 +389,7 @@ class VnfLcmController(wsgi.Controller):
         placement_attr = default_vim.get('placement_attr', {})
 
         try:
-            with context.session.begin(subtransactions=True):
+            with context.session.begin(nested=True):
                 vnf_db = vnfm_db.VNF(id=vnf_id,
                              tenant_id=tenant_id,
                              name=name,
@@ -403,13 +407,15 @@ class VnfLcmController(wsgi.Controller):
                         id=uuidutils.generate_uuid(), vnf_id=vnf_id,
                         key=key, value=str(value))
                     context.session.add(arg)
+                context.session.commit()
+
         except DBDuplicateEntry as e:
             raise exceptions.DuplicateEntity(
                 _type="vnf",
                 entry=e.columns)
 
     def _destroy_vnf(self, context, vnf_instance):
-        with context.session.begin(subtransactions=True):
+        with context.session.begin(nested=True):
             if vnf_instance.id:
                 now = timeutils.utcnow()
                 updated_values = {'deleted_at': now, 'status':
@@ -418,6 +424,7 @@ class VnfLcmController(wsgi.Controller):
                     vnf_id=vnf_instance.id).delete()
                 context.session.query(vnfm_db.VNF).filter_by(
                     id=vnf_instance.id).update(updated_values)
+            context.session.commit()
 
     def _update_package_usage_state(self, context, vnf_package):
         """Update vnf package usage state to IN_USE/NOT_IN_USE
@@ -439,6 +446,9 @@ class VnfLcmController(wsgi.Controller):
     @validation.schema(vnf_lcm.create)
     def create(self, request, body):
         context = request.environ['tacker.context']
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
+
         if not CONF.oslo_policy.enhanced_tacker_policy:
             context.can(vnf_lcm_policies.VNFLCM % 'create')
         try:
@@ -512,7 +522,7 @@ class VnfLcmController(wsgi.Controller):
                                  default_vim, attributes)
                 # get vnf package
                 vnf_package = objects.VnfPackage.get_by_id(context,
-                vnfd.package_uuid, expected_attrs=['vnfd'])
+                vnfd.package_uuid, expected_attrs=[models.VnfPackage.vnfd])
                 # Update VNF Package to IN_USE
                 self._update_package_usage_state(context, vnf_package)
             except Exception:
@@ -543,7 +553,7 @@ class VnfLcmController(wsgi.Controller):
 
         except nfvo.VimDefaultNotDefined as exc:
             raise webob.exc.HTTPBadRequest(explanation=str(exc))
-        except(sqlexc.SQLAlchemyError, Exception) as exc:
+        except (sqlexc.SQLAlchemyError, Exception) as exc:
             raise webob.exc.HTTPInternalServerError(
                 explanation=str(exc))
         except webob.exc.HTTPNotFound as e:
@@ -608,12 +618,16 @@ class VnfLcmController(wsgi.Controller):
     @wsgi.expected_errors((http_client.FORBIDDEN, http_client.NOT_FOUND))
     def show(self, request, id):
         context = request.environ['tacker.context']
-        if not CONF.oslo_policy.enhanced_tacker_policy:
-            context.can(vnf_lcm_policies.VNFLCM % 'show')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
+
         vnf_instance = self._get_vnf_instance(context, id)
         if CONF.oslo_policy.enhanced_tacker_policy:
             context.can(vnf_lcm_policies.VNFLCM % 'show',
                         target=self._get_policy_target(vnf_instance))
+        else:
+            context.can(vnf_lcm_policies.VNFLCM % 'show',
+                        target={'project_id': vnf_instance.tenant_id})
 
         return self._view_builder.show(vnf_instance)
 
@@ -628,6 +642,9 @@ class VnfLcmController(wsgi.Controller):
                                            'all_records'})
     def index(self, request):
         context = request.environ['tacker.context']
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
+
         if not CONF.oslo_policy.enhanced_tacker_policy:
             context.can(vnf_lcm_policies.VNFLCM % 'index')
 
@@ -643,7 +660,8 @@ class VnfLcmController(wsgi.Controller):
 
         # get maximum record size per page
         if allrecords != 'yes':
-            limit = CONF.vnf_lcm.vnf_instance_num
+            if not CONF.oslo_policy.enhanced_tacker_policy:
+                limit = CONF.vnf_lcm.vnf_instance_num
 
             # get next page marker object from nextpage id
             if nextpage:
@@ -665,6 +683,9 @@ class VnfLcmController(wsgi.Controller):
                     vnf_lcm_policies.VNFLCM % 'index',
                     target=self._get_policy_target(vnf_instance),
                     fatal=False)]
+            if allrecords != 'yes':
+                limit = CONF.vnf_lcm.vnf_instance_num
+                result = result[:limit]
 
         result = self._view_builder.index(result)
 
@@ -695,7 +716,8 @@ class VnfLcmController(wsgi.Controller):
         vnf_instance.destroy(context)
         self._destroy_vnf(context, vnf_instance)
         vnf_package = objects.VnfPackage.get_by_id(context,
-                vnf_package_vnfd.package_uuid, expected_attrs=['vnfd'])
+                vnf_package_vnfd.package_uuid,
+                expected_attrs=[models.VnfPackage.vnfd])
         self._update_package_usage_state(context, vnf_package)
 
     @wsgi.response(http_client.NO_CONTENT)
@@ -703,11 +725,16 @@ class VnfLcmController(wsgi.Controller):
                            http_client.CONFLICT))
     def delete(self, request, id):
         context = request.environ['tacker.context']
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         vnf_instance = self._get_vnf_instance(context, id)
         if CONF.oslo_policy.enhanced_tacker_policy:
             context.can(vnf_lcm_policies.VNFLCM % 'delete',
                         target=self._get_policy_target(vnf_instance))
+        else:
+            context.can(vnf_lcm_policies.VNFLCM % 'delete',
+                        target={'project_id': vnf_instance.tenant_id})
 
         vnf = self._get_vnf(context, id)
         self._delete(context, vnf_instance, vnf)
@@ -779,14 +806,17 @@ class VnfLcmController(wsgi.Controller):
     @validation.schema(vnf_lcm.instantiate)
     def instantiate(self, request, id, body):
         context = request.environ['tacker.context']
-        if not CONF.oslo_policy.enhanced_tacker_policy:
-            context.can(vnf_lcm_policies.VNFLCM % 'instantiate')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         vnf = self._get_vnf(context, id)
         vnf_instance = self._get_vnf_instance(context, id)
         if CONF.oslo_policy.enhanced_tacker_policy:
             context.can(vnf_lcm_policies.VNFLCM % 'instantiate',
                         target=self._get_policy_target(vnf_instance))
+        else:
+            context.can(vnf_lcm_policies.VNFLCM % 'instantiate',
+                        target={'project_id': vnf_instance.tenant_id})
 
         return self._instantiate(context, vnf_instance, vnf, body)
 
@@ -798,6 +828,8 @@ class VnfLcmController(wsgi.Controller):
     @check_vnf_status_and_error_point(action="terminate",
         status=[constants.ACTIVE])
     def _terminate(self, context, vnf_instance, vnf, request_body):
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
         req_body = utils.convert_camelcase_to_snakecase(request_body)
         terminate_vnf_req = \
             objects.TerminateVnfRequest.obj_from_primitive(
@@ -834,14 +866,18 @@ class VnfLcmController(wsgi.Controller):
     @validation.schema(vnf_lcm.terminate)
     def terminate(self, request, id, body):
         context = request.environ['tacker.context']
-        if not CONF.oslo_policy.enhanced_tacker_policy:
-            context.can(vnf_lcm_policies.VNFLCM % 'terminate')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         vnf = self._get_vnf(context, id)
         vnf_instance = self._get_vnf_instance(context, id)
         if CONF.oslo_policy.enhanced_tacker_policy:
             context.can(vnf_lcm_policies.VNFLCM % 'terminate',
                         target=self._get_policy_target(vnf_instance))
+        else:
+            context.can(vnf_lcm_policies.VNFLCM % 'terminate',
+                        target={'project_id': vnf_instance.tenant_id})
+
         return self._terminate(context, vnf_instance, vnf, body)
 
     @check_vnf_status_and_error_point(action="heal",
@@ -894,14 +930,17 @@ class VnfLcmController(wsgi.Controller):
     @validation.schema(vnf_lcm.heal)
     def heal(self, request, id, body):
         context = request.environ['tacker.context']
-        if not CONF.oslo_policy.enhanced_tacker_policy:
-            context.can(vnf_lcm_policies.VNFLCM % 'heal')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         vnf = self._get_vnf(context, id)
         vnf_instance = self._get_vnf_instance(context, id)
         if CONF.oslo_policy.enhanced_tacker_policy:
             context.can(vnf_lcm_policies.VNFLCM % 'heal',
                         target=self._get_policy_target(vnf_instance))
+        else:
+            context.can(vnf_lcm_policies.VNFLCM % 'heal',
+                        target={'project_id': vnf_instance.tenant_id})
 
         if vnf_instance.instantiation_state not in \
            [fields.VnfInstanceState.INSTANTIATED]:
@@ -923,13 +962,20 @@ class VnfLcmController(wsgi.Controller):
     @wsgi.expected_errors((http_client.FORBIDDEN, http_client.NOT_FOUND))
     def show_lcm_op_occs(self, request, id):
         context = request.environ['tacker.context']
-        context.can(vnf_lcm_policies.VNFLCM % 'show_lcm_op_occs')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         try:
             vnf_lcm_op_occs = objects.VnfLcmOpOcc.get_by_id(context, id)
+            vnf_instance = self._get_vnf_instance(
+                context, vnf_lcm_op_occs.vnf_instance_id)
+            context.can(vnf_lcm_policies.VNFLCM % 'show_lcm_op_occs',
+                        target={'project_id': vnf_instance.tenant_id})
         except exceptions.NotFound as occ_e:
             return self._make_problem_detail(str(occ_e),
                 404, title='VnfLcmOpOcc NOT FOUND')
+        except exceptions.PolicyNotAuthorized:
+            raise
         except Exception as e:
             LOG.error(traceback.format_exc())
             return self._make_problem_detail(str(e),
@@ -941,12 +987,21 @@ class VnfLcmController(wsgi.Controller):
     @wsgi.expected_errors((http_client.FORBIDDEN, http_client.NOT_FOUND))
     def update(self, request, id, body):
         context = request.environ['tacker.context']
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
+
+        vnf_instance = self._get_vnf_instance(context, id)
         if CONF.oslo_policy.enhanced_tacker_policy:
-            vnf_instance = self._get_vnf_instance(context, id)
             context.can(vnf_lcm_policies.VNFLCM % 'update_vnf',
                         target=self._get_policy_target(vnf_instance))
         else:
-            context.can(vnf_lcm_policies.VNFLCM % 'update_vnf')
+            context.can(vnf_lcm_policies.VNFLCM % 'update_vnf',
+                    target={'project_id': vnf_instance.tenant_id})
+
+        if (vnf_instance.instantiation_state == 'NOT_INSTANTIATED'
+                and 'vimConnectionInfo' in body):
+            msg = 'vimConnectionInfo cannot be modified in NOT_INSTANTIATED.'
+            return self._make_problem_detail(msg, 400, title='Bad Request')
 
         # get body
         body_data = {}
@@ -956,6 +1011,8 @@ class VnfLcmController(wsgi.Controller):
         body_data['vnfd_id'] = body.get('vnfdId')
         if (body.get('vnfdId') is None and body.get('vnfPkgId')):
             body_data['vnf_pkg_id'] = body.get('vnfPkgId')
+        body_data['metadata'] = body.get('metadata')
+        body_data['vim_connection_info'] = body.get('vimConnectionInfo')
 
         # According to the ETSI NFV SOL document,
         # there is no API request/response
@@ -1345,7 +1402,7 @@ class VnfLcmController(wsgi.Controller):
 
         if vnf_info['before_error_point'] == fields.ErrorPoint.INITIAL:
             vnf_lcm_op_occs_id = uuidutils.generate_uuid()
-            timestamp = datetime.datetime.utcnow()
+            timestamp = timeutils.utcnow()
             operation_params = {
                 'type': scale_vnf_request.type,
                 'aspect_id': scale_vnf_request.aspect_id,
@@ -1425,8 +1482,8 @@ class VnfLcmController(wsgi.Controller):
                            http_client.NOT_FOUND, http_client.CONFLICT))
     def scale(self, request, id, body):
         context = request.environ['tacker.context']
-        if not CONF.oslo_policy.enhanced_tacker_policy:
-            context.can(vnf_lcm_policies.VNFLCM % 'scale')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         try:
             vnf_info = self._vnfm_plugin.get_vnf(context, id)
@@ -1437,6 +1494,9 @@ class VnfLcmController(wsgi.Controller):
             if CONF.oslo_policy.enhanced_tacker_policy:
                 context.can(vnf_lcm_policies.VNFLCM % 'scale',
                             target=self._get_policy_target(vnf_instance))
+            else:
+                context.can(vnf_lcm_policies.VNFLCM % 'scale',
+                            target={'project_id': vnf_instance.tenant_id})
             if not vnf_instance.instantiated_vnf_info.scale_status:
                 return self._make_problem_detail(
                     'NOT SCALE VNF', 409, title='NOT SCALE VNF')
@@ -1485,10 +1545,16 @@ class VnfLcmController(wsgi.Controller):
                            http_client.NOT_FOUND, http_client.CONFLICT))
     def rollback(self, request, id):
         context = request.environ['tacker.context']
-        context.can(vnf_lcm_policies.VNFLCM % 'rollback')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         try:
             vnf_lcm_op_occs = objects.VnfLcmOpOcc.get_by_id(context, id)
+            vnf_instance = self._get_vnf_instance(
+                context, vnf_lcm_op_occs.vnf_instance_id)
+            context.can(vnf_lcm_policies.VNFLCM % 'rollback',
+                        target={'project_id': vnf_instance.tenant_id})
+
             if vnf_lcm_op_occs.operation_state != 'FAILED_TEMP':
                 return self._make_problem_detail(
                     'OperationState IS NOT FAILED_TEMP',
@@ -1513,8 +1579,6 @@ class VnfLcmController(wsgi.Controller):
 
             vnf_info = self._get_rollback_vnf(
                 context, vnf_lcm_op_occs.vnf_instance_id)
-            vnf_instance = self._get_vnf_instance(
-                context, vnf_lcm_op_occs.vnf_instance_id)
 
             inst_vnf_info = vnf_instance.instantiated_vnf_info
             if inst_vnf_info is not None:
@@ -1537,6 +1601,8 @@ class VnfLcmController(wsgi.Controller):
         except webob.exc.HTTPNotFound as inst_e:
             return self._make_problem_detail(
                 str(inst_e), 404, title='VNF NOT FOUND')
+        except exceptions.PolicyNotAuthorized:
+            raise
         except Exception as e:
             LOG.error(traceback.format_exc())
             return self._make_problem_detail(
@@ -1555,7 +1621,7 @@ class VnfLcmController(wsgi.Controller):
                            http_client.NOT_FOUND, http_client.CONFLICT))
     @validation.schema(vnf_lcm.cancel)
     def cancel(self, request, id, body):
-        """SOL003 v3.5.1 5.4.17 Resource: Cancel operation task
+        """SOL003 v2.6.1 5.4.17 Resource: Cancel operation task
 
         @param request: A request object
         @param id: Identifier of a VNF lifecycle management operation
@@ -1573,7 +1639,9 @@ class VnfLcmController(wsgi.Controller):
         """
 
         context = request.environ['tacker.context']
-        context.can(vnf_lcm_policies.VNFLCM % 'cancel')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
+
         req_body = utils.convert_camelcase_to_snakecase(body)
         _ = objects.CancelMode(context=context, **req_body)
 
@@ -1581,9 +1649,13 @@ class VnfLcmController(wsgi.Controller):
             vnf_lcm_op_occs = objects.VnfLcmOpOcc.get_by_id(context, id)
             vnf_instance = self._get_vnf_instance(
                 context, vnf_lcm_op_occs.vnf_instance_id)
+            context.can(vnf_lcm_policies.VNFLCM % 'cancel',
+                        target={'project_id': vnf_instance.tenant_id})
         except (webob.exc.HTTPNotFound, exceptions.NotFound) as e:
             return self._make_problem_detail(
                 str(e), 404, title='VNF NOT FOUND')
+        except exceptions.PolicyNotAuthorized:
+            raise
         except Exception as e:
             LOG.error(traceback.format_exc())
             return self._make_problem_detail(
@@ -1652,26 +1724,32 @@ class VnfLcmController(wsgi.Controller):
                            http_client.NOT_FOUND))
     def fail(self, request, id):
         context = request.environ['tacker.context']
-        context.can(vnf_lcm_policies.VNFLCM % 'fail')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         try:
             vnf_lcm_op_occs = objects.VnfLcmOpOcc.get_by_id(context, id)
             operation = vnf_lcm_op_occs.operation
 
+            vnf_instance_id = vnf_lcm_op_occs.vnf_instance_id
+            vnf_instance = self._get_vnf_instance(context, vnf_instance_id)
+            context.can(vnf_lcm_policies.VNFLCM % 'fail',
+                        target={'project_id': vnf_instance.tenant_id})
+
             if (vnf_lcm_op_occs.operation_state
                     != fields.LcmOccsOperationState.FAILED_TEMP):
                 return self._make_problem_detail(
                     'Transitions to FAIL from state %s is not allowed' %
                     vnf_lcm_op_occs.operation_state, 409, title='Conflict')
 
-            vnf_instance_id = vnf_lcm_op_occs.vnf_instance_id
-            vnf_instance = self._get_vnf_instance(context, vnf_instance_id)
         except webob.exc.HTTPNotFound as e:
             return self._make_problem_detail(
                 str(e), 404, title='VNF NOT FOUND')
         except exceptions.NotFound as e:
             return self._make_problem_detail(
                 str(e), 404, title='VNF LCM NOT FOUND')
+        except exceptions.PolicyNotAuthorized:
+            raise
         except Exception as e:
             LOG.error(traceback.format_exc())
             return self._make_problem_detail(
@@ -1682,7 +1760,7 @@ class VnfLcmController(wsgi.Controller):
 
             vnf_lcm_op_occs.operation_state = "FAILED"
             vnf_lcm_op_occs.state_entered_time = \
-                datetime.datetime.utcnow().isoformat()
+                timeutils.utcnow().isoformat()
             vnf_lcm_op_occs.updated_at = vnf_lcm_op_occs.state_entered_time
 
             error_details = objects.ProblemDetails(
@@ -1741,7 +1819,8 @@ class VnfLcmController(wsgi.Controller):
                            http_client.NOT_FOUND, http_client.CONFLICT))
     def retry(self, request, id):
         context = request.environ['tacker.context']
-        context.can(vnf_lcm_policies.VNFLCM % 'retry')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         try:
             vnf_lcm_op_occs = objects.VnfLcmOpOcc.get_by_id(context, id)
@@ -1753,14 +1832,6 @@ class VnfLcmController(wsgi.Controller):
             return self._make_problem_detail(str(exc),
                 500, title='Internal Server Error')
 
-        # operation state checking
-        if vnf_lcm_op_occs.operation_state != \
-           fields.LcmOccsOperationState.FAILED_TEMP:
-            error_msg = ('Cannot proceed with operation_state %s'
-                % vnf_lcm_op_occs.operation_state)
-            return self._make_problem_detail(error_msg,
-                409, title='Conflict')
-
         # get vnf
         try:
             vnf = self._get_vnf(context, vnf_lcm_op_occs.vnf_instance_id)
@@ -1776,16 +1847,28 @@ class VnfLcmController(wsgi.Controller):
         try:
             vnf_instance = objects.VnfInstance.get_by_id(
                 context, vnf_lcm_op_occs.vnf_instance_id)
+            context.can(vnf_lcm_policies.VNFLCM % 'retry',
+                        target={'project_id': vnf_instance.tenant_id})
         except exceptions.VnfInstanceNotFound:
             msg = (_("Can not find requested vnf instance: %s")
                 % vnf_lcm_op_occs.vnf_instance_id)
             return self._make_problem_detail(msg,
                 404, title='Not Found')
+        except exceptions.PolicyNotAuthorized:
+            raise
         except Exception as exc:
             LOG.exception(exc)
             return self._make_problem_detail(str(exc),
                 500, title='Internal Server Error')
 
+        # operation state checking
+        if vnf_lcm_op_occs.operation_state != \
+           fields.LcmOccsOperationState.FAILED_TEMP:
+            error_msg = ('Cannot proceed with operation_state %s'
+                % vnf_lcm_op_occs.operation_state)
+            return self._make_problem_detail(error_msg,
+                409, title='Conflict')
+
         operation = vnf_lcm_op_occs.operation
         body = jsonutils.loads(vnf_lcm_op_occs.operation_params)
         vnf['before_error_point'] = vnf_lcm_op_occs.error_point
@@ -1907,14 +1990,17 @@ class VnfLcmController(wsgi.Controller):
     @validation.schema(vnf_lcm.change_ext_conn)
     def change_ext_conn(self, request, id, body):
         context = request.environ['tacker.context']
-        if not CONF.oslo_policy.enhanced_tacker_policy:
-            context.can(vnf_lcm_policies.VNFLCM % 'change_ext_conn')
+        LOG.debug("Start %s with context: %s" % (
+            inspect.currentframe().f_code.co_name, context.to_dict()))
 
         vnf = self._get_vnf(context, id)
         vnf_instance = self._get_vnf_instance(context, id)
         if CONF.oslo_policy.enhanced_tacker_policy:
             context.can(vnf_lcm_policies.VNFLCM % 'change_ext_conn',
                         target=self._get_policy_target(vnf_instance))
+        else:
+            context.can(vnf_lcm_policies.VNFLCM % 'change_ext_conn',
+                        target={'project_id': vnf_instance.tenant_id})
         if (vnf_instance.instantiation_state !=
                 fields.VnfInstanceState.INSTANTIATED):
             return self._make_problem_detail(
