@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # Copyright 2011 VMware, Inc.
 # All Rights Reserved.
 #
@@ -24,10 +22,11 @@ from oslo_config import cfg
 import oslo_i18n
 from oslo_service import service as common_service
 
-from tacker import _i18n
-_i18n.enable_lazy()
+from tacker._i18n import _
 from tacker.common import config
+from tacker import objects
 from tacker import service
+from tacker.sol_refactored import objects as sol_objects
 
 
 oslo_i18n.install("tacker")
@@ -36,6 +35,8 @@ oslo_i18n.install("tacker")
 def main():
     # the configuration will be read into the cfg.CONF global data structure
     config.init(sys.argv[1:])
+    objects.register_all()
+    sol_objects.register_all()
     if not cfg.CONF.config_file:
         sys.exit(_("ERROR: Unable to find configuration file via the default"
                    " search paths (~/.tacker/, ~/, /etc/tacker/, /etc/) and"
@@ -44,7 +45,8 @@ def main():
     try:
         tacker_api = service.serve_wsgi(service.TackerApiService)
         launcher = common_service.launch(cfg.CONF, tacker_api,
-                                         workers=cfg.CONF.api_workers or None)
+                                         workers=cfg.CONF.api_workers or None,
+                                         restart_method='mutate')
         launcher.wait()
     except KeyboardInterrupt:
         pass
