@@ -1,8 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2013, 2014 Intel Corporation.
-# Copyright 2013, 2014 Isaku Yamahata <isaku.yamahata at intel com>
-#                                     <isaku.yamahata at gmail com>
 # All Rights Reserved.
 #
 #
@@ -19,11 +15,13 @@
 #    under the License.
 #
 
-import logging as log
+from oslo_log import log as logging
 
 import stevedore.named
 
-LOG = log.getLogger(__name__)
+from tacker._i18n import _
+
+LOG = logging.getLogger(__name__)
 
 
 class DriverManager(object):
@@ -45,11 +43,10 @@ class DriverManager(object):
                 LOG.error(msg)
                 raise SystemExit(msg)
             drivers[type_] = ext
-
         self._drivers = dict((type_, ext.obj)
                              for (type_, ext) in drivers.items())
-        LOG.info(_("Registered drivers from %(namespace)s: %(keys)s"),
-                 {'namespace': namespace, 'keys': self._drivers.keys()})
+        LOG.debug("Registered drivers from %(namespace)s: %(keys)s",
+                  {'namespace': namespace, 'keys': self._drivers.keys()})
 
     @staticmethod
     def _driver_name(driver):
