@@ -16,14 +16,15 @@
 """Context: context for security/db session."""
 
 import copy
-import datetime
 
 from castellan.common.credentials import keystone_password
 from oslo_config import cfg
 from oslo_context import context as oslo_context
 from oslo_db.sqlalchemy import enginefacade
+from oslo_utils import timeutils
 
 from tacker.common import exceptions
+from tacker.common.ext_oauth2_auth import ExtOAuth2Auth
 from tacker.db import api as db_api
 from tacker import policy
 
@@ -52,7 +53,7 @@ class ContextBase(oslo_context.RequestContext):
         self.user_name = user_name
 
         if not timestamp:
-            timestamp = datetime.datetime.utcnow()
+            timestamp = timeutils.utcnow()
         self.timestamp = timestamp
         # self.is_advsvc = is_advsvc
         # if self.is_advsvc is None:
@@ -131,7 +132,7 @@ class ContextBase(oslo_context.RequestContext):
         return context
 
     def can(self, action, target=None, fatal=True):
-        """Verifies that the given action is valid on the target in this context.
+        """Verifies that the given action is valid on the target.
 
         :param action: string representing the action to be checked.
         :param target: dictionary representing the object of the action
@@ -148,11 +149,14 @@ class ContextBase(oslo_context.RequestContext):
         :return: returns a non-False value (not necessarily "True") if
             authorized and False if not authorized and fatal is False.
         """
-        if target is None:
-            target = {'project_id': self.tenant_id,
-                      'user_id': self.user_id}
+        tgt = {
+            'project_id': self.tenant_id,
+            'user_id': self.user_id
+        }
+        if target is not None:
+            tgt.update(target)
         try:
-            return policy.authorize(self, action, target)
+            return policy.authorize(self, action, tgt)
         except exceptions.Forbidden:
             if fatal:
                 raise
@@ -214,6 +218,8 @@ def is_user_context(context):
 
 
 def generate_tacker_service_context():
+    if CONF.ext_oauth2_auth.use_ext_oauth2_auth:
+        return ExtOAuth2Auth()
     return keystone_password.KeystonePassword(
         password=CONF.keystone_authtoken.password,
         auth_url=CONF.keystone_authtoken.auth_url,
