@@ -13,16 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from oslo_db.sqlalchemy import models
 from sqlalchemy.ext import declarative
 from sqlalchemy import orm
 
-from tacker.openstack.common.db.sqlalchemy import models
-
 
 class TackerBase(models.ModelBase):
     """Base class for Tacker Models."""
 
     __table_args__ = {'mysql_engine': 'InnoDB'}
+    __allow_unmapped__ = True
 
     def __iter__(self):
         self._i = iter(orm.object_mapper(self).columns)
