@@ -15,13 +15,10 @@
 
 import abc
 
-import six
-
 from tacker.api import extensions
 
 
-@six.add_metaclass(abc.ABCMeta)
-class VimAbstractDriver(extensions.PluginInterface):
+class VimAbstractDriver(extensions.PluginInterface, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def get_type(self):
@@ -44,7 +41,7 @@ class VimAbstractDriver(extensions.PluginInterface):
         pass
 
     @abc.abstractmethod
-    def register_vim(self, context, vim_obj):
+    def register_vim(self, vim_obj):
         """Register VIM object in to NFVO plugin
 
         Validate, encode and store VIM information for deploying VNFs.
@@ -52,7 +49,7 @@ class VimAbstractDriver(extensions.PluginInterface):
         pass
 
     @abc.abstractmethod
-    def deregister_vim(self, context, vim_obj):
+    def deregister_vim(self, vim_obj):
         """Deregister VIM object from NFVO plugin
 
         Cleanup VIM data and delete VIM information
@@ -60,7 +57,7 @@ class VimAbstractDriver(extensions.PluginInterface):
         pass
 
     @abc.abstractmethod
-    def authenticate_vim(self, context, vim_obj):
+    def authenticate_vim(self, vim_obj):
         """Authenticate VIM connection parameters
 
         Validate authentication credentials and connectivity of VIM
@@ -68,7 +65,7 @@ class VimAbstractDriver(extensions.PluginInterface):
         pass
 
     @abc.abstractmethod
-    def encode_vim_auth(self, context, vim_id, auth):
+    def encode_vim_auth(self, vim_id, auth):
         """Encrypt VIM credentials
 
         Encrypt and store VIM sensitive information such as password
@@ -76,7 +73,7 @@ class VimAbstractDriver(extensions.PluginInterface):
         pass
 
     @abc.abstractmethod
-    def delete_vim_auth(self, context, vim_id, auth):
+    def delete_vim_auth(self, vim_id, auth):
         """Delete VIM auth keys
 
         Delete VIM sensitive information such as keys from file system or DB
