@@ -139,8 +139,10 @@ class VnfInstanceTaskState(BaseTackerEnum):
     TERMINATING = 'TERMINATING'
     SCALING = 'SCALING'
     ERROR = 'ERROR'
+    DB_SYNCHRONIZING = 'DB_SYNCHRONIZING'
 
-    ALL = (INSTANTIATING, HEALING, TERMINATING, SCALING, ERROR)
+    ALL = (INSTANTIATING, HEALING, TERMINATING,
+           SCALING, ERROR, DB_SYNCHRONIZING)
 
 
 class VnfInstanceTaskStateField(BaseEnumField):
@@ -180,6 +182,18 @@ class VnfInstanceTerminationTypeField(BaseEnumField):
     AUTO_TYPE = VnfInstanceTerminationType()
 
 
+# SOL003 5.5.4.6 Enumeration: CancelModeType
+class VnfInstanceCancelModeType(BaseTackerEnum):
+    FORCEFUL = 'FORCEFUL'
+    GRACEFUL = 'GRACEFUL'
+
+    ALL = (FORCEFUL, GRACEFUL)
+
+
+class VnfInstanceCancelTypeField(BaseEnumField):
+    AUTO_TYPE = VnfInstanceCancelModeType()
+
+
 class VnfcState(BaseTackerEnum):
     STARTED = 'STARTED'
     STOPPED = 'STOPPED'
