@@ -2110,6 +2110,17 @@ _expected_resource_changes_change_vnfpkg = {
     ]
 }
 
+_expected_modifications_triggered_by_vnfpkg_change = {
+    'vnfdId': 'new_vnfd_id',
+    'metadata': {
+        'VDU_VNFc_mapping': {
+            'VDU1': ['a-001', 'a-010', 'a-011'],
+            'VDU2': ['b-001'],
+            'VDU3': ['c-001']
+        }
+    },
+}
+
 # lcmocc_info_example
 _lcmocc_modify_value = {
     'id': 'test-1',
@@ -2327,12 +2338,36 @@ class TestLcmOpOccUtils(base.BaseTestCase):
 
     def test_update_lcmocc_change_vnfpkg(self):
         # prepare
-        inst_saved = objects.VnfInstanceV2()
+        inst_saved = objects.VnfInstanceV2(
+            vnfdId="old_vnfd_id",
+            vnfProvider="Company",
+            vnfProductName="Sample VNF",
+            vnfSoftwareVersion="1.0",
+            vnfdVersion="1.0",
+            metadata={
+                'VDU_VNFc_mapping': {
+                    'VDU1': ['a-001', 'a-010', 'a-011'],
+                    'VDU2': ['b-0']
+                }
+            }
+        )
         inst_saved.instantiatedVnfInfo = (
             objects.VnfInstanceV2_InstantiatedVnfInfo.from_dict(
                 _inst_info_example_1))
-        inst_saved.vnfdId = 'old_vnfd_id'
-        inst = objects.VnfInstanceV2()
+        inst = objects.VnfInstanceV2(
+            vnfdId="new_vnfd_id",
+            vnfProvider="Company",
+            vnfProductName="Sample VNF",
+            vnfSoftwareVersion="1.0",
+            vnfdVersion="1.0",
+            metadata={
+                'VDU_VNFc_mapping': {
+                    'VDU1': ['a-001', 'a-010', 'a-011'],
+                    'VDU2': ['b-001'],
+                    'VDU3': ['c-001']
+                }
+            }
+        )
         inst.instantiatedVnfInfo = (
             objects.VnfInstanceV2_InstantiatedVnfInfo.from_dict(
                 _inst_info_example_5))
@@ -2346,6 +2381,9 @@ class TestLcmOpOccUtils(base.BaseTestCase):
         self.assertEqual(
             _expected_resource_changes_change_vnfpkg,
             self._sort_resource_changes(lcmocc['resourceChanges']))
+        self.assertEqual(
+            _expected_modifications_triggered_by_vnfpkg_change,
+            lcmocc['modificationsTriggeredByVnfPkgChange'])
 
     @mock.patch.object(objects.base.TackerPersistentObject, 'get_by_id')
     def test_get_lcmocc(self, mock_lcmocc):
@@ -2381,27 +2419,26 @@ class TestLcmOpOccUtils(base.BaseTestCase):
     def test_make_lcmocc_links(self):
         lcmocc = objects.VnfLcmOpOccV2(
             id='test-1', vnfInstanceId='instance-1', operation='INSTANTIATE')
+        lcmocc = lcmocc.to_dict()
         endpoint = 'http://127.0.0.1:9890'
 
-        expected_result = objects.VnfLcmOpOccV2_Links()
-        expected_result.self = objects.Link(
-            href=f'{endpoint}/vnflcm/v2/vnf_lcm_op_occs/{lcmocc.id}')
-        expected_result.vnfInstance = objects.Link(
-            href=f'{endpoint}/vnflcm/v2/vnf_instances/{lcmocc.vnfInstanceId}')
-        expected_result.retry = objects.Link(
-            href=f'{endpoint}/vnflcm/v2/vnf_lcm_op_occs/{lcmocc.id}/retry')
-        expected_result.rollback = objects.Link(
-            href=f'{endpoint}/vnflcm/v2/vnf_lcm_op_occs/{lcmocc.id}/rollback')
-        expected_result.fail = objects.Link(
-            href=f'{endpoint}/vnflcm/v2/vnf_lcm_op_occs/{lcmocc.id}/fail')
+        lcmocc_id = lcmocc['id']
+        inst_id = lcmocc['vnfInstanceId']
+        h_self = f'{endpoint}/vnflcm/v2/vnf_lcm_op_occs/{lcmocc_id}'
+        h_inst = f'{endpoint}/vnflcm/v2/vnf_instances/{inst_id}'
+        h_retry = f'{endpoint}/vnflcm/v2/vnf_lcm_op_occs/{lcmocc_id}/retry'
+        h_rback = f'{endpoint}/vnflcm/v2/vnf_lcm_op_occs/{lcmocc_id}/rollback'
+        h_fail = f'{endpoint}/vnflcm/v2/vnf_lcm_op_occs/{lcmocc_id}/fail'
+        expected_result = {
+            'self': {'href': h_self},
+            'vnfInstance': {'href': h_inst},
+            'retry': {'href': h_retry},
+            'rollback': {'href': h_rback},
+            'fail': {'href': h_fail}
+        }
 
         result = lcmocc_utils.make_lcmocc_links(lcmocc, endpoint)
-        self.assertEqual(expected_result.self.href, result.self.href)
-        self.assertEqual(expected_result.vnfInstance.href,
-                         result.vnfInstance.href)
-        self.assertEqual(expected_result.retry.href, result.retry.href)
-        self.assertEqual(expected_result.rollback.href, result.rollback.href)
-        self.assertEqual(expected_result.fail.href, result.fail.href)
+        self.assertEqual(expected_result, result)
 
     def test_make_lcmocc_notif_data(self):
         subsc_short = objects.LccnSubscriptionV2(
