@@ -13,14 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import copy
-from datetime import datetime
 import ddt
 from http import client as http_client
-import os
 import requests
 from unittest import mock
 
 from oslo_policy import policy as oslo_policy
+from oslo_utils import timeutils
 from oslo_utils import uuidutils
 
 from tacker.common.exceptions import PolicyNotAuthorized
@@ -41,6 +40,7 @@ from tacker.sol_refactored.nfvo import nfvo_client
 from tacker.sol_refactored import objects
 from tacker.sol_refactored.objects.v2 import fields
 from tacker.tests.unit.db import base as db_base
+from tacker.tests import utils
 
 
 objects.register_all()
@@ -124,6 +124,8 @@ CONF = config.CONF
 
 def get_test_data_policy_instantiate():
     rules = {POLICY_NAME.format('instantiate'): "vendor:%(vendor)s"}
+    rules_admin = {POLICY_NAME.format('instantiate'):
+                   "(vendor:%(vendor)s or role:admin)"}
     test_data = [
         # 'expected_status_code': http_client.ACCEPTED
         {
@@ -138,6 +140,18 @@ def get_test_data_policy_instantiate():
             'roles': ['VENDOR_all'],
             'expected_status_code': http_client.ACCEPTED
         },
+        {
+            'vnf_instance_updates': {'vnfProvider': 'all'},
+            'rules': rules,
+            'roles': ['VENDOR_all'],
+            'expected_status_code': http_client.ACCEPTED
+        },
+        {
+            'vnf_instance_updates': {'vnfProvider': 'all'},
+            'rules': rules_admin,
+            'roles': ['admin'],
+            'expected_status_code': http_client.ACCEPTED
+        },
         # 'expected_status_code': http_client.FORBIDDEN
         {
             'vnf_instance_updates': {'vnfProvider': 'provider_A'},
@@ -151,6 +165,12 @@ def get_test_data_policy_instantiate():
             'roles': ['VENDOR_provider_B'],
             'expected_status_code': http_client.FORBIDDEN
         },
+        {
+            'vnf_instance_updates': {'vnfProvider': 'all'},
+            'rules': rules,
+            'roles': ['VENDOR_provider_A'],
+            'expected_status_code': http_client.FORBIDDEN
+        },
     ]
     return test_data
 
@@ -163,6 +183,20 @@ def get_test_data_policy_vnf_instantiated(action, success_status_code):
         access_info={"key1": 'value1', "key2": 'value2'},
         extra={'area': 'area_A@region_A'}
     )
+    vim_connection_info_area_all_region_a = objects.VimConnectionInfo(
+        id='f8c35bd0-4d67-4436-9f11-14b8a84c92aa',
+        vimId='f8c35bd0-4d67-4436-9f11-14b8a84c92aa',
+        vimType='openstack',
+        access_info={"key1": 'value1', "key2": 'value2'},
+        extra={'area': 'all@region_A'}  # special role
+    )
+    vim_connection_info_area_all_region_all = objects.VimConnectionInfo(
+        id='f8c35bd0-4d67-4436-9f11-14b8a84c92aa',
+        vimId='f8c35bd0-4d67-4436-9f11-14b8a84c92aa',
+        vimType='openstack',
+        access_info={"key1": 'value1', "key2": 'value2'},
+        extra={'area': 'all@all'}  # special role
+    )
     vim_connection_info_without_area = objects.VimConnectionInfo(
         id='f8c35bd0-4d67-4436-9f11-14b8a84c92aa',
         vimId='f8c35bd0-4d67-4436-9f11-14b8a84c92aa',
@@ -177,11 +211,24 @@ def get_test_data_policy_vnf_instantiated(action, success_status_code):
         'vnfProvider': 'provider_A',
         'vimConnectionInfo': {'vim1': vim_connection_info_without_area}
     }
+    vnf_instance_updates_area_all_region_a = {
+        'vnfProvider': 'provider_A',
+        'vimConnectionInfo': {'vim1': vim_connection_info_area_all_region_a}
+    }
+    vnf_instance_updates_area_all_region_all = {
+        'vnfProvider': 'provider_A',
+        'vimConnectionInfo': {'vim1': vim_connection_info_area_all_region_all}
+    }
     rule_area_vendor_tenant = {
         POLICY_NAME.format(action):
             "area:%(area)s and vendor:%(vendor)s and "
             "tenant:%(tenant)s"
     }
+    rule_area_vendor_tenant_admin = {
+        POLICY_NAME.format(action):
+            "area:%(area)s and vendor:%(vendor)s and "
+            "tenant:%(tenant)s or role:admin"
+    }
     rule_vendor = {
         POLICY_NAME.format(action): "vendor:%(vendor)s"
     }
@@ -227,6 +274,62 @@ def get_test_data_policy_vnf_instantiated(action, success_status_code):
             ],
             'expected_status_code': success_status_code
         },
+        {
+            'vnf_instance_updates': vnf_instance_updates_area_all_region_a,
+            'tenant': 'tenant_A',
+            'rules': rule_area_vendor_tenant,
+            'roles': [
+                'AREA_all@region_A',
+                'VENDOR_provider_A',
+                'TENANT_tenant_A'
+            ],
+            'expected_status_code': success_status_code
+        },
+        {
+            'vnf_instance_updates': vnf_instance_updates_area_all_region_a,
+            'tenant': 'tenant_A',
+            'rules': rule_area_vendor_tenant,
+            'roles': [
+                'AREA_all@all',
+                'VENDOR_provider_A',
+                'TENANT_tenant_A'
+            ],
+            'expected_status_code': success_status_code
+        },
+        {
+            'vnf_instance_updates': vnf_instance_updates_area_all_region_all,
+            'tenant': 'tenant_A',
+            'rules': rule_area_vendor_tenant,
+            'roles': [
+                'AREA_all@all',
+                'VENDOR_provider_A',
+                'TENANT_tenant_A'
+            ],
+            'expected_status_code': success_status_code
+        },
+        {
+            'vnf_instance_updates': vnf_instance_updates_area_all_region_all,
+            'tenant': 'tenant_A',
+            'rules': rule_area_vendor_tenant_admin,
+            'roles': [
+                'AREA_all@region_A',
+                'VENDOR_provider_A',
+                'TENANT_tenant_A',
+                'admin'
+            ],
+            'expected_status_code': success_status_code
+        },
+        {
+            'vnf_instance_updates': vnf_instance_updates,
+            'tenant': 'all',  # special role
+            'rules': rule_area_vendor_tenant,
+            'roles': [
+                'AREA_area_A@region_A',
+                'VENDOR_provider_A',
+                'TENANT_all'
+            ],
+            'expected_status_code': success_status_code
+        },
         # 'expected_status_code': http_client.FORBIDDEN
         {
             'vnf_instance_updates': vnf_instance_updates,
@@ -395,7 +498,40 @@ def get_test_data_policy_vnf_instantiated(action, success_status_code):
                 'VENDOR_provider_B',
             ],
             'expected_status_code': http_client.FORBIDDEN
-        }
+        },
+        {
+            'vnf_instance_updates': vnf_instance_updates_area_all_region_all,
+            'tenant': 'tenant_A',
+            'rules': rule_area_vendor_tenant,
+            'roles': [
+                'AREA_all@region_A',
+                'VENDOR_provider_A',
+                'TENANT_tenant_A'
+            ],
+            'expected_status_code': http_client.FORBIDDEN
+        },
+        {
+            'vnf_instance_updates': vnf_instance_updates_area_all_region_a,
+            'tenant': 'tenant_A',
+            'rules': rule_area_vendor_tenant,
+            'roles': [
+                'AREA_all@region_B',
+                'VENDOR_provider_A',
+                'TENANT_tenant_A'
+            ],
+            'expected_status_code': http_client.FORBIDDEN
+        },
+        {
+            'vnf_instance_updates': vnf_instance_updates,
+            'tenant': 'all',  # special role
+            'rules': rule_area_vendor_tenant,
+            'roles': [
+                'AREA_area_A@region_A',
+                'VENDOR_provider_A',
+                'TENANT_tenant_A'
+            ],
+            'expected_status_code': http_client.FORBIDDEN
+        },
     ]
     return test_data
 
@@ -416,6 +552,12 @@ def get_test_data_policy_delete():
             'roles': ['VENDOR_all'],
             'expected_status_code': http_client.NO_CONTENT
         },
+        {
+            'vnf_instance_updates': {'vnfProvider': 'all'},  # special role
+            'rules': rules,
+            'roles': ['VENDOR_all'],
+            'expected_status_code': http_client.NO_CONTENT
+        },
         # 'expected_status_code': http_client.FORBIDDEN
         {
             'vnf_instance_updates': {'vnfProvider': 'provider_A'},
@@ -429,6 +571,12 @@ def get_test_data_policy_delete():
             'roles': ['VENDOR_provider_B'],
             'expected_status_code': http_client.FORBIDDEN
         },
+        {
+            'vnf_instance_updates': {'vnfProvider': 'all'},  # special role
+            'rules': rules,
+            'roles': ['VENDOR_provider_B'],
+            'expected_status_code': http_client.FORBIDDEN
+        },
     ]
     return test_data
 
@@ -488,48 +636,48 @@ def get_test_data_policy_index():
         area='area_A@region_A', tenant='tenant_A')
     # OK
     test_data.append({
-        'vnf_instance_list': [inst_1],
+        'vnf_instance_list': [inst_1.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': ['AREA_area_A@region_A', 'VENDOR_provider_A',
                   'TENANT_tenant_A'],
         'expected_vnf_inst_ids': [inst_1.id]
     })
     test_data.append({
-        'vnf_instance_list': [inst_1],
+        'vnf_instance_list': [inst_1.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': ['AREA_all@all', 'VENDOR_all', 'TENANT_all'],
         'expected_vnf_inst_ids': [inst_1.id]
     })
     test_data.append({
-        'vnf_instance_list': [inst_1],
+        'vnf_instance_list': [inst_1.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': ['AREA_all@region_A', 'VENDOR_all', 'TENANT_all'],
         'expected_vnf_inst_ids': [inst_1.id]
     })
     # wrong region role
     test_data.append({
-        'vnf_instance_list': [inst_1],
+        'vnf_instance_list': [inst_1.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': ['AREA_all@region_B', 'VENDOR_all', 'TENANT_all'],
         'expected_vnf_inst_ids': []
     })
     # wrong area role
     test_data.append({
-        'vnf_instance_list': [inst_1],
+        'vnf_instance_list': [inst_1.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': ['AREA_area_B@region_A', 'VENDOR_provider_A', 'TENANT_all'],
         'expected_vnf_inst_ids': []
     })
     # wrong vendor role
     test_data.append({
-        'vnf_instance_list': [inst_1],
+        'vnf_instance_list': [inst_1.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': ['AREA_area_A@region_A', 'VENDOR_provider_B', 'TENANT_all'],
         'expected_vnf_inst_ids': []
     })
     # wrong tenant role
     test_data.append({
-        'vnf_instance_list': [inst_1],
+        'vnf_instance_list': [inst_1.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': ['AREA_area_A@region_A', 'VENDOR_provider_A', 'TENANT_B'],
         'expected_vnf_inst_ids': []
@@ -539,7 +687,7 @@ def get_test_data_policy_index():
         'ETSINFV.OPENSTACK_KEYSTONE.V_3', 'INSTANTIATED', 'provider_A',
         tenant='tenant_A')
     test_data.append({
-        'vnf_instance_list': [inst_2],
+        'vnf_instance_list': [inst_2.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': ['AREA_area_A@region_A', 'VENDOR_provider_A'],
         'expected_vnf_inst_ids': []
@@ -549,7 +697,7 @@ def get_test_data_policy_index():
         'ETSINFV.OPENSTACK_KEYSTONE.V_3', 'NOT_INSTANTIATED', 'provider_A',
         tenant='tenant_A')
     test_data.append({
-        'vnf_instance_list': [inst_3],
+        'vnf_instance_list': [inst_3.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': ['VENDOR_provider_A'],
         'expected_vnf_inst_ids': [inst_3.id]
@@ -560,7 +708,7 @@ def get_test_data_policy_index():
         tenant='namespace_A')
     # OK
     test_data.append({
-        'vnf_instance_list': [inst_4],
+        'vnf_instance_list': [inst_4.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': [
             'AREA_area_A@region_A',
@@ -569,7 +717,7 @@ def get_test_data_policy_index():
         'expected_vnf_inst_ids': [inst_4.id]
     })
     test_data.append({
-        'vnf_instance_list': [inst_4],
+        'vnf_instance_list': [inst_4.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': [
             'AREA_all@region_A',
@@ -578,7 +726,7 @@ def get_test_data_policy_index():
         'expected_vnf_inst_ids': [inst_4.id]
     })
     test_data.append({
-        'vnf_instance_list': [inst_4],
+        'vnf_instance_list': [inst_4.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': [
             'AREA_all@all',
@@ -588,7 +736,7 @@ def get_test_data_policy_index():
     })
     # wrong region role
     test_data.append({
-        'vnf_instance_list': [inst_4],
+        'vnf_instance_list': [inst_4.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': [
             'AREA_all@region_B',
@@ -598,7 +746,7 @@ def get_test_data_policy_index():
     })
     # wrong region role
     test_data.append({
-        'vnf_instance_list': [inst_4],
+        'vnf_instance_list': [inst_4.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': [
             'AREA_area_B@region_A',
@@ -608,7 +756,7 @@ def get_test_data_policy_index():
     })
     # wrong vendor role
     test_data.append({
-        'vnf_instance_list': [inst_4],
+        'vnf_instance_list': [inst_4.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': [
             'AREA_area_A@region_A',
@@ -618,7 +766,7 @@ def get_test_data_policy_index():
     })
     # wrong namespace
     test_data.append({
-        'vnf_instance_list': [inst_4],
+        'vnf_instance_list': [inst_4.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': [
             'AREA_all@all',
@@ -630,7 +778,7 @@ def get_test_data_policy_index():
     inst_5 = make_vnf_instance(
         'kubernetes', 'INSTANTIATED', 'provider_A', area='area_A@region_A')
     test_data.append({
-        'vnf_instance_list': [inst_5],
+        'vnf_instance_list': [inst_5.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': [
             'AREA_area_A@region_A',
@@ -642,7 +790,7 @@ def get_test_data_policy_index():
         'kubernetes', 'NOT_INSTANTIATED', 'provider_A')
     # OK
     test_data.append({
-        'vnf_instance_list': [inst_6],
+        'vnf_instance_list': [inst_6.to_dict()],
         'rules': rule_area_vendor_tenant,
         'roles': [
             'VENDOR_provider_A',
@@ -682,8 +830,8 @@ class TestVnflcmV2(db_base.SqlTestCase):
             # required fields
             id=uuidutils.generate_uuid(),
             operationState=op_state,
-            stateEnteredTime=datetime.utcnow(),
-            startTime=datetime.utcnow(),
+            stateEnteredTime=timeutils.utcnow(),
+            startTime=timeutils.utcnow(),
             vnfInstanceId=inst.id,
             operation=fields.LcmOperationType.INSTANTIATE,
             isAutomaticInvocation=False,
@@ -761,14 +909,15 @@ class TestVnflcmV2(db_base.SqlTestCase):
         result = self.controller.create(request=self.request, body=body)
         self.assertEqual(201, result.status)
 
-    @mock.patch.object(inst_utils, 'get_inst_all')
-    def test_index(self, mock_inst):
+    def test_index(self):
         request = requests.Request()
         request.context = self.context
         request.GET = {'filter': f'(eq,vnfdId,{SAMPLE_VNFD_ID})'}
-        mock_inst.return_value = [objects.VnfInstanceV2(
+        inst = objects.VnfInstanceV2(
             id='inst-1', vnfdId=SAMPLE_VNFD_ID,
-            instantiationState='NOT_INSTANTIATED')]
+            instantiationState='NOT_INSTANTIATED')
+        self.controller._inst_view.get_dict_all = mock.Mock(
+            return_value=[inst.to_dict()])
 
         result = self.controller.index(request)
         self.assertEqual(200, result.status)
@@ -1125,9 +1274,9 @@ class TestVnflcmV2(db_base.SqlTestCase):
 
     @mock.patch.object(subsc_utils, 'test_notification')
     def test_subscription_create_201(self, mock_test):
-        cur_dir = os.path.dirname(__file__)
-        sample_cert = os.path.join(
-            cur_dir, "../samples/sample_cert", "notification_client_cert.pem")
+        sample_cert = utils.test_sample(
+            "unit/sol_refactored/samples/sample_cert",
+            "notification_client_cert.pem")
         CONF.v2_vnfm.notification_mtls_client_cert_file = sample_cert
         body_1 = {
             "callbackUri": "http://127.0.0.1:6789/notification",
@@ -1251,15 +1400,16 @@ class TestVnflcmV2(db_base.SqlTestCase):
             request=self.request, id='subsc-1')
         self.assertEqual(204, result.status)
 
-    @mock.patch.object(lcmocc_utils, 'get_lcmocc_all')
-    def test_lcm_op_occ_list(self, mock_lcmocc):
+    def test_lcm_op_occ_list(self):
         request = requests.Request()
         request.context = self.context
         request.GET = {
             'filter': f'(eq,operation,'
                       f'{fields.LcmOperationType.INSTANTIATE})'}
-        mock_lcmocc.return_value = [objects.VnfLcmOpOccV2(
-            id='lcmocc-1', operation='INSTANTIATE', vnfInstanceId='inst-1')]
+        lcmocc = objects.VnfLcmOpOccV2(
+            id='lcmocc-1', operation='INSTANTIATE', vnfInstanceId='inst-1')
+        self.controller._lcmocc_view.get_dict_all = mock.Mock(
+            return_value=[lcmocc.to_dict()])
 
         result = self.controller.lcm_op_occ_list(request)
         self.assertEqual(200, result.status)
@@ -1297,8 +1447,8 @@ class TestVnflcmV2(db_base.SqlTestCase):
             # required fields
             id=uuidutils.generate_uuid(),
             operationState=fields.LcmOperationStateType.FAILED_TEMP,
-            stateEnteredTime=datetime.utcnow(),
-            startTime=datetime.utcnow(),
+            stateEnteredTime=timeutils.utcnow(),
+            startTime=timeutils.utcnow(),
             vnfInstanceId='inst-1',
             operation=fields.LcmOperationType.INSTANTIATE,
             isAutomaticInvocation=False,
@@ -1321,8 +1471,8 @@ class TestVnflcmV2(db_base.SqlTestCase):
             # required fields
             id=uuidutils.generate_uuid(),
             operationState=fields.LcmOperationStateType.FAILED_TEMP,
-            stateEnteredTime=datetime.utcnow(),
-            startTime=datetime.utcnow(),
+            stateEnteredTime=timeutils.utcnow(),
+            startTime=timeutils.utcnow(),
             vnfInstanceId='inst-1',
             operation=fields.LcmOperationType.HEAL,
             isAutomaticInvocation=False,
@@ -1362,8 +1512,8 @@ class TestVnflcmV2(db_base.SqlTestCase):
             # required fields
             id=uuidutils.generate_uuid(),
             operationState=fields.LcmOperationStateType.FAILED_TEMP,
-            stateEnteredTime=datetime.utcnow(),
-            startTime=datetime.utcnow(),
+            stateEnteredTime=timeutils.utcnow(),
+            startTime=timeutils.utcnow(),
             vnfInstanceId='inst-1',
             operation=fields.LcmOperationType.INSTANTIATE,
             isAutomaticInvocation=False,
@@ -1386,8 +1536,8 @@ class TestVnflcmV2(db_base.SqlTestCase):
             # required fields
             id=uuidutils.generate_uuid(),
             operationState=fields.LcmOperationStateType.FAILED_TEMP,
-            stateEnteredTime=datetime.utcnow(),
-            startTime=datetime.utcnow(),
+            stateEnteredTime=timeutils.utcnow(),
+            startTime=timeutils.utcnow(),
             vnfInstanceId='inst-1',
             operation=fields.LcmOperationType.HEAL,
             isAutomaticInvocation=False,
@@ -1465,11 +1615,14 @@ class TestVnflcmV2(db_base.SqlTestCase):
     def test_lcm_op_occ_fail(self, mocked_send_lcmocc_notification):
         # prepare
         lcmocc = self._prepare_db_for_fail()
+        before_state_entered_time = lcmocc.stateEnteredTime
 
         op_state = []
+        op_state_entered_time = []
 
         def _store_state(context, lcmocc, inst, endpoint):
             op_state.append(lcmocc.operationState)
+            op_state_entered_time.append(lcmocc.stateEnteredTime)
 
         mocked_send_lcmocc_notification.side_effect = _store_state
 
@@ -1480,6 +1633,10 @@ class TestVnflcmV2(db_base.SqlTestCase):
         self.assertEqual(1, mocked_send_lcmocc_notification.call_count)
         self.assertEqual(fields.LcmOperationStateType.FAILED, op_state[0])
 
+        # check stateEnteredTime
+        self.assertNotEqual(before_state_entered_time,
+                            op_state_entered_time[0])
+
         # check grant_req and grant are deleted
         self.assertRaises(sol_ex.GrantRequestOrGrantNotFound,
             lcmocc_utils.get_grant_req_and_grant, self.context, lcmocc)
@@ -1907,8 +2064,8 @@ class TestVnflcmV2EnhancedPolicy(TestVnflcmV2):
             # required fields
             id=uuidutils.generate_uuid(),
             operationState=op_state,
-            stateEnteredTime=datetime.utcnow(),
-            startTime=datetime.utcnow(),
+            stateEnteredTime=timeutils.utcnow(),
+            startTime=timeutils.utcnow(),
             vnfInstanceId=inst.id,
             operation=fields.LcmOperationType.INSTANTIATE,
             isAutomaticInvocation=False,
@@ -1986,6 +2143,8 @@ class TestVnflcmV2EnhancedPolicy(TestVnflcmV2):
         request = requests.Request()
         ctx = context.Context('fake', 'fake', roles=roles)
         ctx.api_version = api_version.APIVersion("2.0.0")
+        if 'admin' in roles:
+            ctx.is_admin = True
         request.context = ctx
         return request
 
@@ -2343,11 +2502,11 @@ class TestVnflcmV2EnhancedPolicy(TestVnflcmV2):
 
     @ddt.data(*get_test_data_policy_index())
     @ddt.unpack
-    @mock.patch.object(inst_utils, 'get_inst_all')
-    def test_index_enhanced_policy(self, mock_inst, vnf_instance_list,
+    def test_index_enhanced_policy(self, vnf_instance_list,
             rules, roles, expected_vnf_inst_ids):
         self._overwrite_policy(rules)
-        mock_inst.return_value = vnf_instance_list
+        self.controller._inst_view.get_dict_all = mock.Mock(
+            return_value=vnf_instance_list)
         request = self._fake_request(roles)
         request.GET = {}
 
