@@ -25,6 +25,7 @@ import socket
 import ssl
 import sys
 import time
+from urllib import parse
 
 import eventlet.wsgi
 # eventlet.patcher.monkey_patch(all=False, socket=True, thread=True)
@@ -148,6 +149,20 @@ def expected_errors(errors):
     return decorator
 
 
+# TODO(ueha): Remove this along with the deprecated APIs in the first major
+# Tacker release after version 9.0.0 (2023.1 Antelope release).
+def deprecate_legacy_warning(req):
+    parts = parse.urlparse(req.url)
+    p = parts.path.split('/')
+    if 'vims' not in p[2]:
+        # Emit warning log if the request is Legacy API not related to VIM
+        LOG.warning(
+            'The Legacy API interface has been deprecated. This API '
+            f'(path={parts.path}) will be removed in the first major '
+            'release after the Tacker server version 9.0.0 (2023.1 Antelope '
+            'release).')
+
+
 class Server(object):
     """Server class to manage multiple WSGI sockets and applications."""
 
@@ -192,18 +207,17 @@ class Server(object):
                                      ": %s") % CONF.ssl_ca_file)
 
         def wrap_ssl(sock):
-            ssl_kwargs = {
-                'server_side': True,
-                'certfile': CONF.ssl_cert_file,
-                'keyfile': CONF.ssl_key_file,
-                'cert_reqs': ssl.CERT_NONE,
-            }
+            ssl_context = ssl.SSLContext(ssl.PROTOCOL_TLS_SERVER)
+            ssl_context.load_cert_chain(CONF.ssl_cert_file, CONF.ssl_key_file)
 
             if CONF.ssl_ca_file:
-                ssl_kwargs['ca_certs'] = CONF.ssl_ca_file
-                ssl_kwargs['cert_reqs'] = ssl.CERT_REQUIRED
+                ssl_context.verify_mode = ssl.CERT_REQUIRED
+                ssl_context.load_verify_locations(CONF.ssl_ca_file)
+            else:
+                ssl_context.check_hostname = False
+                ssl_context.verify_mode = ssl.CERT_NONE
 
-            return ssl.wrap_socket(sock, **ssl_kwargs)
+            return ssl_context.wrap_socket(sock, server_side=True)
 
         sock = None
         retry_until = time.time() + CONF.retry_until_window
@@ -329,6 +343,7 @@ class Middleware(object):
 
     @webob.dec.wsgify
     def __call__(self, req):
+        deprecate_legacy_warning(req)
         response = self.process_request(req)
         if response:
             return response
@@ -569,7 +584,7 @@ class RequestDeserializer(object):
             deserializer = self.get_body_deserializer(content_type)
         except exception.InvalidContentType:
             with excutils.save_and_reraise_exception():
-                LOG.debug("Unable to deserialize body as provided "
+                LOG.error("Unable to deserialize body as provided "
                           "Content-Type")
 
         if isinstance(deserializer, ZipDeserializer):
@@ -1014,7 +1029,7 @@ class Resource(Application):
             msg_dict = dict(url=request.url, exception=e)
             msg = _("%(url)s returned a fault: %(exception)s") % msg_dict
 
-        LOG.info(msg)
+        LOG.debug(msg)
 
         return response
 
